===
zyc
===


.. image:: https://img.shields.io/pypi/v/zyc.svg
        :target: https://pypi.python.org/pypi/zyc


A GUI utility for searching and selecting parts and footprints for use with `SKiDL <https://pypi.org/project/skidl/>`_.


* Free software: MIT license
* Documentation: https://devbisme.github.io/zyc .


Features
--------

* Keyword search and selection of parts in KiCad libraries.
* Keyword search and selection of footprints in KiCad libraries.
* Copy-and-paste part instances into SKiDL code.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
